@@ -3,5 +3,9 @@ from .getaddressesbalancesrequest import GetAddressesBalancesRequest
 from .getlastbalanceupdatetransactionrequest import GetLastBalanceUpdateTransactionRequest
 from .getutxosetrequest import GetUTXOSetRequest
 from .getverboseaddressesbalancesrequest import GetVerboseAddressesBalancesRequest
+from .getutxosetforaddressrequest import GetUTXOSetForAddressRequest
 
-__all__ = ['BlockRequest', 'GetAddressesBalancesRequest', 'GetLastBalanceUpdateTransactionRequest', 'GetUTXOSetRequest', 'GetVerboseAddressesBalancesRequest']
+__all__ = [
+    'BlockRequest', 'GetAddressesBalancesRequest', 'GetLastBalanceUpdateTransactionRequest',
+    'GetUTXOSetRequest', 'GetVerboseAddressesBalancesRequest', 'GetUTXOSetForAddressRequest'
+]
