@@ -6,10 +6,12 @@ from .getlastbalanceupdatetransactionmodel import GetLastBalanceUpdateTransactio
 from .getverboseaddressesbalancesmodel import GetVerboseAddressesBalancesModel
 from .utxomodel import UTXOModel
 from .verboseaddressbalancemodel import VerboseAddressBalanceModel
+from .getutxosforaddressmodel import GetUTXOsForAddressModel
 # noinspection PyUnresolvedReferences
 from pystratis.api.global_responsemodels import BlockTransactionDetailsModel, BlockModel
 
 __all__ = [
     'AddressBalanceModel', 'AddressIndexerTipModel', 'BalanceChangesModel', 'GetAddressesBalancesModel', 'GetLastBalanceUpdateTransactionModel',
-    'GetVerboseAddressesBalancesModel', 'UTXOModel', 'VerboseAddressBalanceModel', 'BlockModel', 'BlockTransactionDetailsModel'
+    'GetVerboseAddressesBalancesModel', 'UTXOModel', 'VerboseAddressBalanceModel', 'BlockModel', 'BlockTransactionDetailsModel',
+    'GetUTXOsForAddressModel'
 ]
