@@ -1,4 +1,5 @@
 from .federationmembermodel import FederationMemberModel
 from .federationmemberdetailedmodel import FederationMemberDetailedModel
+from .miningstats import MiningStats
 
-__all__ = ['FederationMemberModel', 'FederationMemberDetailedModel']
+__all__ = ['FederationMemberModel', 'FederationMemberDetailedModel', 'MiningStats']
