@@ -1,6 +1,7 @@
 from .whitelistedhashesmodel import WhitelistedHashesModel
 from .votingdatamodel import VotingDataModel
+from .pollstipmodel import PollsTipModel
 # noinspection PyUnresolvedReferences
 from pystratis.api.global_responsemodels import PollViewModel
 
-__all__ = ['WhitelistedHashesModel', 'VotingDataModel', 'PollViewModel']
+__all__ = ['WhitelistedHashesModel', 'VotingDataModel', 'PollViewModel', 'PollsTipModel']
