@@ -1,7 +1,11 @@
 from .straxnode import StraxNode
 from .cirrusnode import CirrusNode
+from .cirrusunity3dnode import CirrusUnity3DNode
 from .cirrusminernode import CirrusMinerNode, StraxMasterNode, CirrusMasterNode
 from .interfluxnodes import InterfluxStraxNode, InterfluxCirrusNode
 from .basenode import BaseNode
 
-__all__ = ['StraxNode', 'CirrusNode', 'CirrusMinerNode', 'InterfluxCirrusNode', 'InterfluxStraxNode', 'BaseNode', 'CirrusMasterNode', 'StraxMasterNode']
+__all__ = [
+    'StraxNode', 'CirrusNode', 'CirrusMinerNode', 'InterfluxCirrusNode', 'InterfluxStraxNode',
+    'BaseNode', 'CirrusMasterNode', 'StraxMasterNode', 'CirrusUnity3DNode'
+]
