@@ -3,10 +3,13 @@ from pystratis.core.networks import CirrusMain, CirrusTest, CirrusRegTest, Strax
 from .basenode import BaseNode
 from pystratis.api.balances import Balances
 from pystratis.api.collateral import Collateral
+from pystratis.api.contract_swagger import ContractSwagger
+from pystratis.api.dynamic_contract import DynamicContract
 from pystratis.api.notifications import Notifications
 from pystratis.api.federation import Federation
 from pystratis.api.smartcontracts import SmartContracts
 from pystratis.api.smartcontractwallet import SmartContractWallet
+from pystratis.api.signalr import SignalR
 from pystratis.api.voting import Voting
 
 
@@ -34,18 +37,24 @@ class CirrusMinerNode(BaseNode):
         if not devmode:
             self._collateral = Collateral(baseuri=self.api_route, network=blockchainnetwork)
             self._endpoints.extend(self._collateral.endpoints)
+        self._contract_swagger = ContractSwagger(baseuri=self.api_route, network=blockchainnetwork)
+        self._dynamic_contract = DynamicContract(baseuri=self.api_route, network=blockchainnetwork)
         self._federation = Federation(baseuri=self.api_route, network=blockchainnetwork)
         self._notifications = Notifications(baseuri=self.api_route, network=blockchainnetwork)
         self._smart_contracts = SmartContracts(baseuri=self.api_route, network=blockchainnetwork)
         self._smart_contract_wallet = SmartContractWallet(baseuri=self.api_route, network=blockchainnetwork)
+        self._signalr = SignalR(baseuri=self.api_route, network=blockchainnetwork)
         self._voting = Voting(baseuri=self.api_route, network=blockchainnetwork)
 
         # Add CirrusMiner specific endpoints to superclass endpoints.
         self._endpoints.extend(self._balances.endpoints)
+        self._endpoints.extend(self._contract_swagger.endpoints)
+        self._endpoints.extend(self._dynamic_contract.endpoints)
         self._endpoints.extend(self._federation.endpoints)
         self._endpoints.extend(self._notifications.endpoints)
         self._endpoints.extend(self._smart_contracts.endpoints)
         self._endpoints.extend(self._smart_contract_wallet.endpoints)
+        self._endpoints.extend(self._signalr.endpoints)
         self._endpoints.extend(self._voting.endpoints)
         self._endpoints.sort()
 
@@ -69,6 +78,24 @@ class CirrusMinerNode(BaseNode):
             raise NotImplementedError('Not implemented in devmode cirrus miner node.')
         return self._collateral
 
+    @property
+    def contract_swagger(self) -> ContractSwagger:
+        """The contract_swagger route.
+
+        Returns:
+            ContractSwagger: A ContractSwagger instance.
+        """
+        return self._contract_swagger
+
+    @property
+    def dynamic_contract(self) -> DynamicContract:
+        """The dynamic contract route.
+
+        Returns:
+            DynamicContract: A DynamicContract instance.
+        """
+        return self._dynamic_contract
+
     @property
     def federation(self) -> Federation:
         """The federation route.
@@ -105,6 +132,15 @@ class CirrusMinerNode(BaseNode):
         """
         return self._smart_contract_wallet
 
+    @property
+    def signalr(self) -> SignalR:
+        """The signalr route.
+
+        Returns:
+            SignalR: A SignalR instance.
+        """
+        return self._signalr
+
     @property
     def voting(self) -> Voting:
         """The voting route.
